# chat_bubbles plugin

![Pub Version](https://img.shields.io/pub/v/chat_bubbles?color=blue)
![likes](https://badges.bar/chat_bubbles/likes)
![popularity](https://badges.bar/chat_bubbles/popularity)
![pub points](https://badges.bar/sentry/pub%20points)
![GitHub](https://img.shields.io/github/license/prahack/chat_bubbles)
![GitHub forks](https://img.shields.io/github/forks/prahack/chat_bubbles)
![GitHub Repo stars](https://img.shields.io/github/stars/prahack/chat_bubbles)
![GitHub last commit](https://img.shields.io/github/last-commit/prahack/chat_bubbles)

Flutter chat bubble widgets, similar to the Whatsapp and more shapes. Easy to use and implement chat bubbles.

## Getting Started

Add this to your package's `pubspec.yaml` file:

```yaml
dependencies:
  chat_bubbles: ^1.0.0
```

## Usage

Then you just have to import the package with

```dart
import 'package:chat_bubbles/chat_bubbles.dart'
```

Now you can use this plugin to implement various types of Chat Bubbles and Date chips.

## Example

### Single bubble example

<img src="https://github.com/prahack/chat_bubbles/blob/master/images/screenshots/single_bubble.png?raw=true"  width="220" height="60" />


```dart
  BubbleSpecialOne(
    text: 'Hi, How are you? ',
    isSender: false,
    color: Colors.purple.shade100,
    textStyle: TextStyle(
      fontSize: 20,
      color: Colors.purple,
      fontStyle: FontStyle.italic,
      fontWeight: FontWeight.bold,
    ),
  ),
```

### Date Chip example

<img src="https://github.com/prahack/chat_bubbles/blob/master/images/screenshots/datechip.png?raw=true"  width="237" height="58" />

```dart
  DateChip(
    date: new DateTime(2021, 5, 7),
    color: Color(0x558AD3D5),
  ),
```

### Main example (Chat View)

<img src="https://github.com/prahack/chat_bubbles/blob/master/images/screenshots/screenshot_1.png?raw=true"  width="250" height="450" />


```dart
   BubbleNormal(
      text: 'bubble normal with tail',
      isSender: false,
      color: Color(0xAF6AD0F5),
      tail: true,
      textStyle: TextStyle(
        fontSize: 20,
        color: Colors.white,
      ),
    ),
    BubbleNormal(
      text: 'bubble normal with tail',
      isSender: true,
      color: Color(0xFFE2FFC7),
      tail: true,
      sent: true,
    ),
    BubbleNormal(
      text: 'bubble normal without tail',
      isSender: false,
      color: Color(0xAF6AD0F5),
      tail: false,
      textStyle: TextStyle(
        fontSize: 20,
        color: Colors.white,
      ),
    ),
    BubbleNormal(
      text: 'bubble normal without tail',
      color: Color(0xFFE2FFC7),
      tail: false,
      seen: true,
    ),
    BubbleSpecialOne(
      text: 'bubble special one with tail',
      isSender: false,
      color: Color(0xAF6AD0F5),
      textStyle: TextStyle(
        fontSize: 20,
        color: Colors.teal,
      ),
    ),
    BubbleSpecialOne(
      text: 'bubble special one with tail',
      color: Color(0xFFE2FFC7),
      seen: true,
    ),
    BubbleSpecialOne(
      text: 'bubble special one without tail',
      isSender: false,
      tail: false,
      color: Color(0xAF6AD0F5),
      textStyle: TextStyle(
        fontSize: 20,
        color: Colors.teal,
      ),
    ),
    BubbleSpecialOne(
      text: 'bubble special one without tail',
      tail: false,
      color: Color(0xFFE2FFC7),
      sent: true,
    ),
    BubbleSpecialTwo(
      text: 'bubble special tow with tail',
      isSender: false,
      color: Color(0xAF6AD0F5),
      textStyle: TextStyle(
        fontSize: 20,
        color: Colors.red,
      ),
    ),
    BubbleSpecialTwo(
      text: 'bubble special tow with tail',
      isSender: true,
      color: Color(0xFFE2FFC7),
      sent: true,
    ),
    BubbleSpecialTwo(
      text: 'bubble special tow without tail',
      isSender: false,
      tail: false,
      color: Color(0xAF6AD0F5),
      textStyle: TextStyle(
        fontSize: 20,
        color: Colors.red,
      ),
    ),
    BubbleSpecialTwo(
      text: 'bubble special tow without tail',
      tail: false,
      color: Color(0xFFE2FFC7),
      delivered: true,
    ),
```

## Issues

Please feel free to [let me know any issue](https://github.com/prahack/chat_bubbles/issues) regarding to this plugin.
